@@ -1,6 +1,7 @@
-from DeepRiver.utils import SequentialLSTM
 from torch import nn
 
+from river_torch.utils import SequentialLSTM
+
 
 def build_torch_mlp_regressor(n_features):
     net = nn.Sequential(
