@@ -2,7 +2,7 @@ import torch
 from torch import nn
 from torch.autograd import Variable
 
-from river_torch.utils.module_finder import get_activation_fn, get_init_fn
+from river_torch.utils.params import get_activation_fn, get_init_fn
 
 
 class DenseBlock(nn.Module):
@@ -48,20 +48,29 @@ class SequentialLSTM(nn.Module):
         )  # lstm
 
     def forward(self, x):
-        h_0 = Variable(
-            torch.zeros(self.num_layers, x.size(0), self.hidden_size)
-        )  # hidden state
-        c_0 = Variable(
-            torch.zeros(self.num_layers, x.size(0), self.hidden_size)
-        )  # internal state
+
         # Propagate input through LSTM
-        output, (hn, cn) = self.lstm(
-            x, (h_0, c_0)
-        )  # lstm with input, hidden, and internal state
+        output, (hn, cn) = self.lstm(x)  # lstm with input, hidden, and internal state
         hn = hn.view(-1, self.hidden_size)  # reshaping the data for Dense layer next
 
         return hn
 
 
-def init_weights(layer: nn.Module, init_fn: str = "xavier_uniform"):
-    init_fn = get_init_fn(init_fn)
+def find_output_layer(net: nn.Sequential) -> nn.Linear:
+    """Return the output layer of a network.
+
+    Parameters
+    ----------
+    net
+        The network to find the output layer of.
+
+    Returns
+    -------
+    nn.Linear
+        The output layer of the network.
+    """
+
+    for layer in list(net.children())[::-1]:
+        if isinstance(layer, nn.Linear):
+            return layer
+    raise ValueError("No dense layer found.")
